# YTDLraw

## Download YouTube Videos AND playlists in almost no time!

Instead of typing long, annoying lines of code to download a YouTube Video,  
just use this Module!  

Quick, reliable Downloads made possible with PyTube